==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/NetNamespaceFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NetNamespaceFluent<A extends io.fabric8.openshift.api.model.NetNamespaceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToEgressIPs(java.lang.Integer index,java.lang.String item);
  public A setToEgressIPs(java.lang.Integer index,java.lang.String item);
  public A addToEgressIPs(java.lang.String... items);
  public A addAllToEgressIPs(java.util.Collection<java.lang.String> items);
  public A removeFromEgressIPs(java.lang.String... items);
  public A removeAllFromEgressIPs(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getEgressIPs();
  public java.lang.String getEgressIP(java.lang.Integer index);
  public java.lang.String getFirstEgressIP();
  public java.lang.String getLastEgressIP();
  public java.lang.String getMatchingEgressIP(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingEgressIP(java.util.function.Predicate<java.lang.String> predicate);
  public A withEgressIPs(java.util.List<java.lang.String> egressIPs);
  public A withEgressIPs(java.lang.String... egressIPs);
  public java.lang.Boolean hasEgressIPs();
  public A addNewEgressIP(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public java.lang.Integer getNetid();
  public A withNetid(java.lang.Integer netid);
  public java.lang.Boolean hasNetid();
  public java.lang.String getNetname();
  public A withNetname(java.lang.String netname);
  public java.lang.Boolean hasNetname();
  
  /**
   * Method is deprecated. use withNetname instead.
   */
  @java.lang.Deprecated
  public A withNewNetname(java.lang.String arg0);
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/NetNamespaceFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NetNamespaceFluent<A extends io.fabric8.openshift.api.model.NetNamespaceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToEgressIPs(java.lang.Integer index,java.lang.String item);
  public A setToEgressIPs(java.lang.Integer index,java.lang.String item);
  public A addToEgressIPs(java.lang.String... items);
  public A addAllToEgressIPs(java.util.Collection<java.lang.String> items);
  public A removeFromEgressIPs(java.lang.String... items);
  public A removeAllFromEgressIPs(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getEgressIPs();
  public java.lang.String getEgressIP(java.lang.Integer index);
  public java.lang.String getFirstEgressIP();
  public java.lang.String getLastEgressIP();
  public java.lang.String getMatchingEgressIP(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingEgressIP(java.util.function.Predicate<java.lang.String> predicate);
  public A withEgressIPs(java.util.List<java.lang.String> egressIPs);
  public A withEgressIPs(java.lang.String... egressIPs);
  public java.lang.Boolean hasEgressIPs();
  public A addNewEgressIP(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public java.lang.Integer getNetid();
  public A withNetid(java.lang.Integer netid);
  public java.lang.Boolean hasNetid();
  public java.lang.String getNetname();
  public A withNetname(java.lang.String netname);
  public java.lang.Boolean hasNetname();
  
  /**
   * Method is deprecated. use withNetname instead.
   */
  @java.lang.Deprecated
  public A withNewNetname(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.NetNamespaceFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}
